@@ -1,8 +1,10 @@
-from marshmallow import fields
+from marshmallow import fields, EXCLUDE
 from cc_py_commons.schemas.camel_case_schema import CamelCaseSchema
 
 class LocationSchema(CamelCaseSchema):
-
+  class Meta:
+      unknown = EXCLUDE
+      
   city = fields.String()
   state = fields.String()
   postcode = fields.String(allow_none=True)
